@@ -4,18 +4,22 @@ import os
 import freetype
 import pytest
 
+test_folder = os.path.realpath(os.path.dirname(__file__))
+
 
 def test_load_ft_face():
     """A smoke test."""
-    assert freetype.Face("../examples/Vera.ttf")
+    p = os.path.join(test_folder, "..", "examples", "Vera.ttf")
+    assert freetype.Face(p)
 
 
 def test_load_ft_face_from_memory():
     """Another smoke test."""
-    with open("../examples/Vera.ttf", mode="rb") as f:
+    p = os.path.join(test_folder, "..", "examples", "Vera.ttf")
+    with open(p, mode="rb") as f:
         assert freetype.Face(f)
 
-    with open("../examples/Vera.ttf", mode="rb") as f:
+    with open(p, mode="rb") as f:
         byte_stream = f.read()
     assert freetype.Face.from_bytes(byte_stream)
 
@@ -25,7 +29,8 @@ def test_bundle_version():
     shared_object = glob.glob(os.path.join(module_dir, "libfreetype*"))
     if shared_object:
         import re
-        with open("../setup-build-freetype.py") as f:
+        p = os.path.join(test_folder, "..", "setup-build-freetype.py")
+        with open(p) as f:
             m = re.findall(r"freetype-(\d+)\.(\d+)\.?(\d+)?\.tar", f.read())
         version = m[0]
         if not version[2]:
